@@ -116,16 +116,29 @@ sub _save_mapping {
         or croak "Can't rename $file.tmp to $file: $!";
 }
 
+sub make_dsn {
+    my ($self, %args) = @_;
+    my $dsn = $self->driver_dsn();
+    return $dsn
+        . ( $dsn =~ /^dbi:[^:]+:$/ ? '' : ';' )
+        . join( ';', map "$_=$args{$_}", keys %args );
+}
+
 sub make_handle {
     my ($self) = @_;
     my $handle;
 
-    # return a handle for this driver, using the mapping
-    if ( my $dbname = $self->{mapping}{ cwd() } ) {
+    # get the database name from the ḿapping
+    my $dbname = $self->{mapping}{ cwd() };
+
+    # if the database still exists, return it
+    if ( grep { $_ eq $dbname } $self->databases() ) {
         $handle = Test::Database::Handle->new(
-            dsn    => $self->dsn($dbname),
-            name   => $dbname,
-            driver => $self,
+            dsn      => $self->dsn($dbname),
+            username => $self->username(),
+            password => $self->password(),
+            name     => $dbname,
+            driver   => $self,
         );
     }
 
@@ -139,6 +152,21 @@ sub make_handle {
     return $handle;
 }
 
+sub version_matches {
+    my ( $self, $request ) = @_;
+    my $version = $self->version();
+    return
+        if exists $request->{version}
+            && $version != $request->{version};
+    return
+        if exists $request->{min_version}
+            && $version < $request->{min_version};
+    return
+        if exists $request->{max_version}
+            && $version >= $request->{max_version};
+    return 1;
+}
+
 #
 # ACCESSORS
 #
@@ -170,7 +198,6 @@ sub connection_info {
 # THESE MUST BE IMPLEMENTED IN THE DERIVED CLASSES
 sub drop_database { die "$_[0] doesn't have a drop_database() method\n" }
 sub _version      { die "$_[0] doesn't have a _version() method\n" }
-sub dsn           { die "$_[0] doesn't have a dsn() method\n" }
 
 # create_database creates the database and returns a handle
 sub create_database {
@@ -188,6 +215,11 @@ sub databases {
 sub is_filebased {0}
 sub _driver_dsn    { join ':', 'dbi', $_[0]->name(), ''; }
 
+sub dsn {
+    my ( $self, $dbname ) = @_;
+    return $self->make_dsn( database => $dbname );
+}
+
 #
 # PRIVATE METHODS
 #
@@ -284,6 +316,14 @@ The decision whether to create a new database or not is made by
 C<Test::Database::Driver> based on the information in the mapper.
 See L<TEMPORARY STORAGE ORGANIZATION> for details.
 
+=item make_dsn( %args )
+
+Return a Data Source Name based on the driver's DSN, with the key/value
+pairs contained in C<%args> as additional parameters.
+
+This is typically used by C<dsn()> to make a DSN for a specific database,
+based on the driver's DSN.
+
 =item name()
 
 =item dbd()
@@ -318,6 +358,12 @@ Return the connection password.
 Return the connection information triplet (C<driver_dsn>, C<username>,
 C<password>).
 
+=item version_matches( $request )
+
+Return a boolean indicating if the driver's version matches the version
+constraints in the given request (see L<Test::Database> documentation's
+section about requests).
+
 =back
 
 The class also provides a few helpful commands that may be useful for driver
@@ -332,7 +378,8 @@ for the driver.
 
 =item dsn( $dbname )
 
-Return a bare Data Source Name, for the database with the given C<$dbname>.
+Build a Data Source Name  for the database with the given C<$dbname>,
+based on the driver's DSN.
 
 =back
 
